@@ -213,6 +213,21 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         )
         return m.groupdict() if m else {}
 
+    @staticmethod
+    def network_path(project: str, resource_id: str,) -> str:
+        """Returns a fully-qualified network string."""
+        return "projects/{project}/global/networks/{resource_id}".format(
+            project=project, resource_id=resource_id,
+        )
+
+    @staticmethod
+    def parse_network_path(path: str) -> Dict[str, str]:
+        """Parses a network path into its component segments."""
+        m = re.match(
+            r"^projects/(?P<project>.+?)/global/networks/(?P<resource_id>.+?)$", path
+        )
+        return m.groupdict() if m else {}
+
     @staticmethod
     def spoke_path(project: str, location: str, spoke: str,) -> str:
         """Returns a fully-qualified spoke string."""
@@ -1245,189 +1260,6 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         # Done; return the response.
         return response
 
-    def deactivate_spoke(
-        self,
-        request: hub.DeactivateSpokeRequest = None,
-        *,
-        name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
-        metadata: Sequence[Tuple[str, str]] = (),
-    ) -> operation.Operation:
-        r"""Deactivates the specified spoke. Deactivating keeps
-        the spoke information for future re-activation, but
-        disconnects the Google Cloud network from non-Google-
-        Cloud network.
-
-        Args:
-            request (google.cloud.networkconnectivity_v1.types.DeactivateSpokeRequest):
-                The request object. The request for
-                [HubService.DeactivateSpoke][google.cloud.networkconnectivity.v1.HubService.DeactivateSpoke].
-            name (str):
-                Required. The name of the spoke to
-                deactivate.
-
-                This corresponds to the ``name`` field
-                on the ``request`` instance; if ``request`` is provided, this
-                should not be set.
-            retry (google.api_core.retry.Retry): Designation of what errors, if any,
-                should be retried.
-            timeout (float): The timeout for this request.
-            metadata (Sequence[Tuple[str, str]]): Strings which should be
-                sent along with the request as metadata.
-
-        Returns:
-            google.api_core.operation.Operation:
-                An object representing a long-running operation.
-
-                The result type for the operation will be :class:`google.cloud.networkconnectivity_v1.types.Spoke` A spoke represents a connection between your Google Cloud network resources
-                   and a non-Google-Cloud network.
-
-                   When you create a spoke, you associate it with a hub.
-                   You must also identify a value for exactly one of the
-                   following fields:
-
-                   -  linked_vpn_tunnels
-                   -  linked_interconnect_attachments
-                   -  linked_router_appliance_instances
-
-        """
-        # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
-        # gotten any keyword arguments that map to the request.
-        has_flattened_params = any([name])
-        if request is not None and has_flattened_params:
-            raise ValueError(
-                "If the `request` argument is set, then none of "
-                "the individual field arguments should be set."
-            )
-
-        # Minor optimization to avoid making a copy if the user passes
-        # in a hub.DeactivateSpokeRequest.
-        # There's no risk of modifying the input as we've already verified
-        # there are no flattened fields.
-        if not isinstance(request, hub.DeactivateSpokeRequest):
-            request = hub.DeactivateSpokeRequest(request)
-            # If we have keyword arguments corresponding to fields on the
-            # request, apply these.
-            if name is not None:
-                request.name = name
-
-        # Wrap the RPC method; this adds retry and timeout information,
-        # and friendly error handling.
-        rpc = self._transport._wrapped_methods[self._transport.deactivate_spoke]
-
-        # Certain fields should be provided within the metadata header;
-        # add these here.
-        metadata = tuple(metadata) + (
-            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
-        )
-
-        # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
-
-        # Wrap the response in an operation future.
-        response = operation.from_gapic(
-            response,
-            self._transport.operations_client,
-            hub.Spoke,
-            metadata_type=common.OperationMetadata,
-        )
-
-        # Done; return the response.
-        return response
-
-    def activate_spoke(
-        self,
-        request: hub.ActivateSpokeRequest = None,
-        *,
-        name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
-        metadata: Sequence[Tuple[str, str]] = (),
-    ) -> operation.Operation:
-        r"""Activates the specified spoke. Activating reconnects
-        the Google Cloud network with the non-Google-Cloud
-        network.
-
-        Args:
-            request (google.cloud.networkconnectivity_v1.types.ActivateSpokeRequest):
-                The request object. The request for
-                [HubService.ActivateSpoke][google.cloud.networkconnectivity.v1.HubService.ActivateSpoke].
-            name (str):
-                Required. The name of the spoke to
-                activate.
-
-                This corresponds to the ``name`` field
-                on the ``request`` instance; if ``request`` is provided, this
-                should not be set.
-            retry (google.api_core.retry.Retry): Designation of what errors, if any,
-                should be retried.
-            timeout (float): The timeout for this request.
-            metadata (Sequence[Tuple[str, str]]): Strings which should be
-                sent along with the request as metadata.
-
-        Returns:
-            google.api_core.operation.Operation:
-                An object representing a long-running operation.
-
-                The result type for the operation will be :class:`google.cloud.networkconnectivity_v1.types.Spoke` A spoke represents a connection between your Google Cloud network resources
-                   and a non-Google-Cloud network.
-
-                   When you create a spoke, you associate it with a hub.
-                   You must also identify a value for exactly one of the
-                   following fields:
-
-                   -  linked_vpn_tunnels
-                   -  linked_interconnect_attachments
-                   -  linked_router_appliance_instances
-
-        """
-        # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
-        # gotten any keyword arguments that map to the request.
-        has_flattened_params = any([name])
-        if request is not None and has_flattened_params:
-            raise ValueError(
-                "If the `request` argument is set, then none of "
-                "the individual field arguments should be set."
-            )
-
-        # Minor optimization to avoid making a copy if the user passes
-        # in a hub.ActivateSpokeRequest.
-        # There's no risk of modifying the input as we've already verified
-        # there are no flattened fields.
-        if not isinstance(request, hub.ActivateSpokeRequest):
-            request = hub.ActivateSpokeRequest(request)
-            # If we have keyword arguments corresponding to fields on the
-            # request, apply these.
-            if name is not None:
-                request.name = name
-
-        # Wrap the RPC method; this adds retry and timeout information,
-        # and friendly error handling.
-        rpc = self._transport._wrapped_methods[self._transport.activate_spoke]
-
-        # Certain fields should be provided within the metadata header;
-        # add these here.
-        metadata = tuple(metadata) + (
-            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
-        )
-
-        # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
-
-        # Wrap the response in an operation future.
-        response = operation.from_gapic(
-            response,
-            self._transport.operations_client,
-            hub.Spoke,
-            metadata_type=common.OperationMetadata,
-        )
-
-        # Done; return the response.
-        return response
-
     def delete_spoke(
         self,
         request: hub.DeleteSpokeRequest = None,
