@@ -484,63 +484,6 @@ class HubServiceGrpcAsyncIOTransport(HubServiceTransport):
             )
         return self._stubs["update_spoke"]
 
-    @property
-    def deactivate_spoke(
-        self,
-    ) -> Callable[[hub.DeactivateSpokeRequest], Awaitable[operations_pb2.Operation]]:
-        r"""Return a callable for the deactivate spoke method over gRPC.
-
-        Deactivates the specified spoke. Deactivating keeps
-        the spoke information for future re-activation, but
-        disconnects the Google Cloud network from non-Google-
-        Cloud network.
-
-        Returns:
-            Callable[[~.DeactivateSpokeRequest],
-                    Awaitable[~.Operation]]:
-                A function that, when called, will call the underlying RPC
-                on the server.
-        """
-        # Generate a "stub function" on-the-fly which will actually make
-        # the request.
-        # gRPC handles serialization and deserialization, so we just need
-        # to pass in the functions for each.
-        if "deactivate_spoke" not in self._stubs:
-            self._stubs["deactivate_spoke"] = self.grpc_channel.unary_unary(
-                "/google.cloud.networkconnectivity.v1.HubService/DeactivateSpoke",
-                request_serializer=hub.DeactivateSpokeRequest.serialize,
-                response_deserializer=operations_pb2.Operation.FromString,
-            )
-        return self._stubs["deactivate_spoke"]
-
-    @property
-    def activate_spoke(
-        self,
-    ) -> Callable[[hub.ActivateSpokeRequest], Awaitable[operations_pb2.Operation]]:
-        r"""Return a callable for the activate spoke method over gRPC.
-
-        Activates the specified spoke. Activating reconnects
-        the Google Cloud network with the non-Google-Cloud
-        network.
-
-        Returns:
-            Callable[[~.ActivateSpokeRequest],
-                    Awaitable[~.Operation]]:
-                A function that, when called, will call the underlying RPC
-                on the server.
-        """
-        # Generate a "stub function" on-the-fly which will actually make
-        # the request.
-        # gRPC handles serialization and deserialization, so we just need
-        # to pass in the functions for each.
-        if "activate_spoke" not in self._stubs:
-            self._stubs["activate_spoke"] = self.grpc_channel.unary_unary(
-                "/google.cloud.networkconnectivity.v1.HubService/ActivateSpoke",
-                request_serializer=hub.ActivateSpokeRequest.serialize,
-                response_deserializer=operations_pb2.Operation.FromString,
-            )
-        return self._stubs["activate_spoke"]
-
     @property
     def delete_spoke(
         self,
